@@ -38,7 +38,7 @@ class ColabCode:
         for tunnel in active_tunnels:
             public_url = tunnel.public_url
             ngrok.disconnect(public_url)
-        url = ngrok.connect(port=self.port)
+        url = ngrok.connect(port=self.port, options={"bind_tls": True})
         print(f"Code Server can be accessed on: {url}")
 
     def _run_code(self):
